@@ -2,7 +2,7 @@
 // timer.cpp
 // ~~~~~~~~~
 //
-// Copyright (c) 2003-2017 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2018 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -10,13 +10,12 @@
 
 #include <iostream>
 #include <boost/asio.hpp>
-#include <boost/date_time/posix_time/posix_time.hpp>
 
 int main()
 {
-  boost::asio::io_service io;
+  boost::asio::io_context io;
 
-  boost::asio::deadline_timer t(io, boost::posix_time::seconds(5));
+  boost::asio::steady_timer t(io, boost::asio::chrono::seconds(5));
   t.wait();
 
   std::cout << "Hello, world!" << std::endl;
