@@ -2,7 +2,7 @@
 // address.cpp
 // ~~~~~~~~~~~
 //
-// Copyright (c) 2003-2017 Christopher M. Kohlhoff (chris at kohlhoff dot com)
+// Copyright (c) 2003-2018 Christopher M. Kohlhoff (chris at kohlhoff dot com)
 //
 // Distributed under the Boost Software License, Version 1.0. (See accompanying
 // file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
@@ -69,14 +69,18 @@ void test()
     (void)addr_v6_value;
 
     std::string string_value = addr1.to_string();
+#if !defined(BOOST_ASIO_NO_DEPRECATED)
     string_value = addr1.to_string(ec);
+#endif // !defined(BOOST_ASIO_NO_DEPRECATED)
 
     // address static functions.
 
+#if !defined(BOOST_ASIO_NO_DEPRECATED)
     addr1 = ip::address::from_string("127.0.0.1");
     addr1 = ip::address::from_string("127.0.0.1", ec);
     addr1 = ip::address::from_string(string_value);
     addr1 = ip::address::from_string(string_value, ec);
+#endif // !defined(BOOST_ASIO_NO_DEPRECATED)
 
     // address comparisons.
 
@@ -98,6 +102,22 @@ void test()
     b = (addr1 >= addr2);
     (void)b;
 
+    // address creation functions.
+
+    addr1 = ip::make_address("127.0.0.1");
+    addr1 = ip::make_address("127.0.0.1", ec);
+    addr1 = ip::make_address(string_value);
+    addr1 = ip::make_address(string_value, ec);
+#if defined(BOOST_ASIO_HAS_STRING_VIEW)
+# if defined(BOOST_ASIO_HAS_STD_STRING_VIEW)
+    std::string_view string_view_value("127.0.0.1");
+# elif defined(BOOST_ASIO_HAS_STD_EXPERIMENTAL_STRING_VIEW)
+    std::experimental::string_view string_view_value("127.0.0.1");
+# endif // defined(BOOST_ASIO_HAS_STD_EXPERIMENTAL_STRING_VIEW)
+    addr1 = ip::make_address(string_view_value);
+    addr1 = ip::make_address(string_view_value, ec);
+#endif // defined(BOOST_ASIO_HAS_STRING_VIEW)
+
     // address I/O.
 
     std::ostringstream os;
