@@ -1,5 +1,6 @@
 var NAVTREEINDEX2 =
 {
+"group__group-Comonad.html#ga181751278bd19a4bfc3c08bd7ddef399":[1,0,1,0],
 "group__group-Comonad.html#ga307479a91a21b7ab06a2bc746b003dcc":[1,0,1,2],
 "group__group-Comonad.html#gaf44692351fd9fe4e76815dfef6ff4478":[1,0,1,1],
 "group__group-Comparable.html":[1,0,2],
@@ -119,34 +120,35 @@ var NAVTREEINDEX2 =
 "group__group-Sequence.html":[1,0,19],
 "group__group-Sequence.html#ga245d8abaf6ba67e64020be51c8366081":[1,0,19,15],
 "group__group-Sequence.html#ga28037560e8f224c53cf6ac168d03a067":[1,0,19,12],
-"group__group-Sequence.html#ga2d4db4ec5ec5bc16fe74f57de12697fd":[1,0,19,22],
+"group__group-Sequence.html#ga2d4db4ec5ec5bc16fe74f57de12697fd":[1,0,19,23],
 "group__group-Sequence.html#ga3410ba833cf1ff1d929fcfda4df2eae1":[1,0,19,4],
-"group__group-Sequence.html#ga35349be79e646c4f5bdd74ec96a846ab":[1,0,19,25],
-"group__group-Sequence.html#ga3779f62fea92af00113a9290f1c680eb":[1,0,19,21],
+"group__group-Sequence.html#ga35349be79e646c4f5bdd74ec96a846ab":[1,0,19,26],
+"group__group-Sequence.html#ga3779f62fea92af00113a9290f1c680eb":[1,0,19,22],
 "group__group-Sequence.html#ga4696efcdee7d95ab4a391bb896a840b5":[1,0,19,11],
-"group__group-Sequence.html#ga497286bf277e6f8e89ddb18661e1033e":[1,0,19,24],
-"group__group-Sequence.html#ga5112e6070d29b4f7fde3f44825da3316":[1,0,19,20],
+"group__group-Sequence.html#ga497286bf277e6f8e89ddb18661e1033e":[1,0,19,25],
+"group__group-Sequence.html#ga5112e6070d29b4f7fde3f44825da3316":[1,0,19,21],
 "group__group-Sequence.html#ga54d141f901866dfab29b052857123bab":[1,0,19,14],
 "group__group-Sequence.html#ga5e84ac3f1eb09c637b6b38ef42dccd8d":[1,0,19,6],
 "group__group-Sequence.html#ga66599f0e1f0749daba759dc661946bdc":[1,0,19,0],
-"group__group-Sequence.html#ga6a4bf8549ce69b5b5b7377aec225a0e3":[1,0,19,29],
+"group__group-Sequence.html#ga6a4bf8549ce69b5b5b7377aec225a0e3":[1,0,19,30],
 "group__group-Sequence.html#ga6f6d5c1f335780c91d29626fde615c78":[1,0,19,10],
 "group__group-Sequence.html#ga80724ec8ecf319a1e695988a69e22f87":[1,0,19,8],
 "group__group-Sequence.html#ga8d302de01b94b4b17f3bd81e09f42920":[1,0,19,19],
 "group__group-Sequence.html#ga9bdde56d805517bce8e387f5bcd1887e":[1,0,19,18],
 "group__group-Sequence.html#gaa18061cd0f63cfaae89abf43ff92b79e":[1,0,19,5],
-"group__group-Sequence.html#gaa5a378d4e71a91e0d6cd3959d9818e8a":[1,0,19,26],
+"group__group-Sequence.html#gaa4d4818952083e3b27c83b0ed645e322":[1,0,19,20],
+"group__group-Sequence.html#gaa5a378d4e71a91e0d6cd3959d9818e8a":[1,0,19,27],
 "group__group-Sequence.html#gac000a79eb7b9d44ecc8982c93daa40e5":[1,0,19,17],
 "group__group-Sequence.html#gac10231310abc86b056585ea0d0e96ef7":[1,0,19,1],
 "group__group-Sequence.html#gac1e182ac088f1990edd739424d30ea07":[1,0,19,7],
 "group__group-Sequence.html#gacefca884b3580664b63238cf8ba33fd3":[1,0,19,2],
-"group__group-Sequence.html#gade78593b3ff51fc5479e1da97142fef5":[1,0,19,27],
+"group__group-Sequence.html#gade78593b3ff51fc5479e1da97142fef5":[1,0,19,28],
 "group__group-Sequence.html#gae1f6a2a9cb70564d43c6b3c663b25dd7":[1,0,19,16],
 "group__group-Sequence.html#gae22a1a184b1b2dd550fa4fa619bed2e9":[1,0,19,3],
 "group__group-Sequence.html#gae70b0815645c7d81bb636a1eed1a65c6":[1,0,19,9],
-"group__group-Sequence.html#gae7a51104a77db79a0407d7d67b034667":[1,0,19,28],
+"group__group-Sequence.html#gae7a51104a77db79a0407d7d67b034667":[1,0,19,29],
 "group__group-Sequence.html#gaec484fb349500149d90717f6e68f7bcd":[1,0,19,13],
-"group__group-Sequence.html#gaf2128be91ad6d32e45db1b8c61f79818":[1,0,19,23],
+"group__group-Sequence.html#gaf2128be91ad6d32e45db1b8c61f79818":[1,0,19,24],
 "group__group-Struct.html":[1,0,20],
 "group__group-Struct.html#ga141761435a7826b3cbe646b4f59eaf0a":[1,0,20,0],
 "group__group-Struct.html#ga983a55dbd93d766fd37689ea32e4ddfb":[1,0,20,3],
@@ -171,20 +173,20 @@ var NAVTREEINDEX2 =
 "group__group-assertions.html#ga41a7490fd94005e6b6a3b6a900207063":[1,7,10],
 "group__group-assertions.html#ga4bf9e0c46c44e21fbe5c5fbb3ace8356":[3,0,0,19,11],
 "group__group-assertions.html#ga4bf9e0c46c44e21fbe5c5fbb3ace8356":[1,7,11],
-"group__group-assertions.html#ga512de1fcd31e8a34931ffb2c891afd36":[3,0,0,19,13],
 "group__group-assertions.html#ga512de1fcd31e8a34931ffb2c891afd36":[1,7,13],
-"group__group-assertions.html#ga5150cd7df438a22056a39529d21562d2":[1,7,15],
-"group__group-assertions.html#ga5150cd7df438a22056a39529d21562d2":[3,0,0,19,15],
-"group__group-assertions.html#ga7af67ae500a237fe350f1bfceb4a5afa":[3,0,0,19,12],
+"group__group-assertions.html#ga512de1fcd31e8a34931ffb2c891afd36":[3,0,0,19,13],
 "group__group-assertions.html#ga7af67ae500a237fe350f1bfceb4a5afa":[1,7,12],
+"group__group-assertions.html#ga7af67ae500a237fe350f1bfceb4a5afa":[3,0,0,19,12],
 "group__group-assertions.html#ga90c1df2cb8eb67e8e0c822eac180b7bc":[3,0,0,19,4],
 "group__group-assertions.html#ga90c1df2cb8eb67e8e0c822eac180b7bc":[1,7,4],
 "group__group-assertions.html#ga9961218055c571b279bb6e07befbba4d":[3,0,0,19,3],
 "group__group-assertions.html#ga9961218055c571b279bb6e07befbba4d":[1,7,3],
 "group__group-assertions.html#gaa7690973ea7b2ba5b6a72a6293fce873":[3,0,0,19,5],
 "group__group-assertions.html#gaa7690973ea7b2ba5b6a72a6293fce873":[1,7,5],
-"group__group-assertions.html#gaa76ba567944adfec0dce60cc20be35bc":[3,0,0,19,14],
-"group__group-assertions.html#gaa76ba567944adfec0dce60cc20be35bc":[1,7,14],
+"group__group-assertions.html#gabf13a9c600ad4fd014ede3c2fd42b1a4":[1,7,14],
+"group__group-assertions.html#gabf13a9c600ad4fd014ede3c2fd42b1a4":[3,0,0,19,14],
+"group__group-assertions.html#gac7aafc41e4dcc7d1f1929fb00f010d2a":[3,0,0,19,15],
+"group__group-assertions.html#gac7aafc41e4dcc7d1f1929fb00f010d2a":[1,7,15],
 "group__group-assertions.html#gae4eb14a3b31e44f433b080d9bc2d14fd":[3,0,0,19,0],
 "group__group-assertions.html#gae4eb14a3b31e44f433b080d9bc2d14fd":[1,7,0],
 "group__group-concepts.html":[1,0],
@@ -215,24 +217,24 @@ var NAVTREEINDEX2 =
 "group__group-core.html#gadc70755c1d059139297814fb3bfeb91e":[1,3,15],
 "group__group-datatypes.html":[1,1],
 "group__group-details.html":[1,8],
-"group__group-details.html#ga1be7a4bd805ffff2882fe54995dc41bd":[1,8,17],
-"group__group-details.html#ga1be7a4bd805ffff2882fe54995dc41bd":[3,0,0,2,25,3],
-"group__group-details.html#ga444e73a2fe13732b802a770b55b4a99c":[1,8,15],
-"group__group-details.html#ga444e73a2fe13732b802a770b55b4a99c":[3,0,0,2,25,1],
-"group__group-details.html#ga4bd17b3ef62e1e275dfe485923fdf666":[1,8,20],
-"group__group-details.html#ga4bd17b3ef62e1e275dfe485923fdf666":[3,0,0,2,25,6],
+"group__group-details.html#ga1be7a4bd805ffff2882fe54995dc41bd":[3,0,0,2,27,1],
+"group__group-details.html#ga1be7a4bd805ffff2882fe54995dc41bd":[1,8,19],
+"group__group-details.html#ga444e73a2fe13732b802a770b55b4a99c":[1,8,14],
+"group__group-details.html#ga444e73a2fe13732b802a770b55b4a99c":[3,0,0,2,25,0],
+"group__group-details.html#ga4bd17b3ef62e1e275dfe485923fdf666":[1,8,17],
+"group__group-details.html#ga4bd17b3ef62e1e275dfe485923fdf666":[3,0,0,2,25,3],
 "group__group-details.html#ga5de7a0132a80e37c73d544ece1e6dd4e":[3,0,0,2,9,0],
 "group__group-details.html#ga5de7a0132a80e37c73d544ece1e6dd4e":[1,8,13],
-"group__group-details.html#ga62fe3327023c37706c827cc82624998b":[3,0,0,2,25,0],
-"group__group-details.html#ga62fe3327023c37706c827cc82624998b":[1,8,14],
-"group__group-details.html#ga6b4ca5cb5cefc6cf77455d7d7ef6f381":[1,8,16],
-"group__group-details.html#ga6b4ca5cb5cefc6cf77455d7d7ef6f381":[3,0,0,2,25,2],
+"group__group-details.html#ga62fe3327023c37706c827cc82624998b":[1,8,18],
+"group__group-details.html#ga62fe3327023c37706c827cc82624998b":[3,0,0,2,27,0],
+"group__group-details.html#ga6b4ca5cb5cefc6cf77455d7d7ef6f381":[1,8,15],
+"group__group-details.html#ga6b4ca5cb5cefc6cf77455d7d7ef6f381":[3,0,0,2,25,1],
 "group__group-details.html#ga9acac3c4609cff5f0957572744c61ec4":[1,8,22],
-"group__group-details.html#gadcf0cf5cb650681b8cac90d94ce52d44":[1,8,18],
-"group__group-details.html#gadcf0cf5cb650681b8cac90d94ce52d44":[3,0,0,2,25,4],
+"group__group-details.html#gadcf0cf5cb650681b8cac90d94ce52d44":[1,8,20],
+"group__group-details.html#gadcf0cf5cb650681b8cac90d94ce52d44":[3,0,0,2,27,2],
 "group__group-details.html#gae85b604ae6c7a386f0fc3631c561091b":[1,8,21],
-"group__group-details.html#gaf8319341c937c45415ae0eae8d656723":[1,8,19],
-"group__group-details.html#gaf8319341c937c45415ae0eae8d656723":[3,0,0,2,25,5],
+"group__group-details.html#gaf8319341c937c45415ae0eae8d656723":[1,8,16],
+"group__group-details.html#gaf8319341c937c45415ae0eae8d656723":[3,0,0,2,25,2],
 "group__group-experimental.html":[1,4],
 "group__group-experimental.html#ga660c0769106006a86948b5b355fad050":[1,4,2],
 "group__group-experimental.html#gaf14876d1f1a3c42ce7a0243d7b263bec":[1,4,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX2 =
 "group__group-functional.html#ga30027c383676084be151ef3c6cf2829f":[1,2,1],
 "group__group-functional.html#ga35c4fc3c5677b9f558150b90e74d3ab1":[1,2,13],
 "group__group-functional.html#ga3a8316acd5efa22c3d1861b62d5df3c2":[1,2,6],
-"group__group-functional.html#ga3b16146e53efcdf9ecbb9a7b21f8cd0b":[1,2,4],
-"group__group-functional.html#ga41ada6b336e9d5bcb101ff0c737acbd0":[1,2,3],
-"group__group-functional.html#ga49ea872ade5ac8f6c10052c495302e89":[1,2,5]
+"group__group-functional.html#ga3b16146e53efcdf9ecbb9a7b21f8cd0b":[1,2,4]
 };
