@@ -40,12 +40,12 @@ var searchData=
   ['boost_5fhana_5fmajor_5fversion',['BOOST_HANA_MAJOR_VERSION',['../group__group-config.html#gac1f8e58978bf4fe02f68ca4646124aee',1,'version.hpp']]],
   ['boost_5fhana_5fminor_5fversion',['BOOST_HANA_MINOR_VERSION',['../group__group-config.html#gafd6a702442b280083efe2690da5621bd',1,'version.hpp']]],
   ['boost_5fhana_5fpatch_5fversion',['BOOST_HANA_PATCH_VERSION',['../group__group-config.html#ga50940f9267eacd0da0d4d8ccbfac8817',1,'version.hpp']]],
-  ['boost_5fhana_5fpp_5fback',['BOOST_HANA_PP_BACK',['../group__group-details.html#ga1be7a4bd805ffff2882fe54995dc41bd',1,'preprocessor.hpp']]],
+  ['boost_5fhana_5fpp_5fback',['BOOST_HANA_PP_BACK',['../group__group-details.html#ga1be7a4bd805ffff2882fe54995dc41bd',1,'struct_macros.hpp']]],
   ['boost_5fhana_5fpp_5fconcat',['BOOST_HANA_PP_CONCAT',['../group__group-details.html#ga444e73a2fe13732b802a770b55b4a99c',1,'preprocessor.hpp']]],
-  ['boost_5fhana_5fpp_5fdrop_5fback',['BOOST_HANA_PP_DROP_BACK',['../group__group-details.html#gadcf0cf5cb650681b8cac90d94ce52d44',1,'preprocessor.hpp']]],
+  ['boost_5fhana_5fpp_5fdrop_5fback',['BOOST_HANA_PP_DROP_BACK',['../group__group-details.html#gadcf0cf5cb650681b8cac90d94ce52d44',1,'struct_macros.hpp']]],
   ['boost_5fhana_5fpp_5fdrop_5ffront',['BOOST_HANA_PP_DROP_FRONT',['../group__group-details.html#ga4bd17b3ef62e1e275dfe485923fdf666',1,'preprocessor.hpp']]],
   ['boost_5fhana_5fpp_5ffront',['BOOST_HANA_PP_FRONT',['../group__group-details.html#gaf8319341c937c45415ae0eae8d656723',1,'preprocessor.hpp']]],
-  ['boost_5fhana_5fpp_5fnarg',['BOOST_HANA_PP_NARG',['../group__group-details.html#ga62fe3327023c37706c827cc82624998b',1,'preprocessor.hpp']]],
+  ['boost_5fhana_5fpp_5fnarg',['BOOST_HANA_PP_NARG',['../group__group-details.html#ga62fe3327023c37706c827cc82624998b',1,'struct_macros.hpp']]],
   ['boost_5fhana_5fpp_5fstringize',['BOOST_HANA_PP_STRINGIZE',['../group__group-details.html#ga6b4ca5cb5cefc6cf77455d7d7ef6f381',1,'preprocessor.hpp']]],
   ['boost_5fhana_5fruntime_5fassert',['BOOST_HANA_RUNTIME_ASSERT',['../group__group-assertions.html#gae4eb14a3b31e44f433b080d9bc2d14fd',1,'assert.hpp']]],
   ['boost_5fhana_5fruntime_5fassert_5fmsg',['BOOST_HANA_RUNTIME_ASSERT_MSG',['../group__group-assertions.html#ga2e25bbdeefb0e5fbf45ffa9227ddb8d2',1,'assert.hpp']]],
