@@ -3,10 +3,6 @@
 //  Software License, Version 1.0. (See accompanying file
 //  LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_
 
-#ifdef _MSC_VER
-#  define _SCL_SECURE_NO_WARNINGS
-#endif
-
 #include <boost/multiprecision/cpp_dec_float.hpp>
 
 #include "test_arithmetic.hpp"
@@ -19,7 +15,7 @@ struct related_type<boost::multiprecision::number< boost::multiprecision::cpp_de
 
 int main()
 {
-   test<boost::multiprecision::number<boost::multiprecision::cpp_dec_float<100, long long, std::allocator<void> >, boost::multiprecision::et_on> >();
+   test<boost::multiprecision::number<boost::multiprecision::cpp_dec_float<100, long long, std::allocator<char> >, boost::multiprecision::et_on> >();
    return boost::report_errors();
 }
 
